'use strict';

const fs = require('fs');
const path = require('path');
const promise = require('./promise');

const appendFile = promise.promisify(fs.appendFile);
const writeFile = promise.promisify(fs.writeFile);
const readFile = promise.promisify(fs.readFile);
const access = promise.promisify(fs.access);

const mkSingleDir = promise.promisify(fs.mkdir);

async function exists(filePath) {
  try {
    await access(filePath, fs.constants.F_OK);

    return true;
  }
  catch (e) {
    return false;
  }
}

async function mkdir(directoryPath) {
  const pathParts = directoryPath.split('/');

  const rootDir = path.parse(directoryPath).root;

  let currentPath = rootDir;
  for ( const pathPart of pathParts ) {
    currentPath = path.join(currentPath, pathPart);
    if ( !await exists(currentPath) ) {
      await mkSingleDir(currentPath);
    }
  }
}

module.exports = {
  appendFile,
  writeFile,
  readFile,
  exists,
  mkdir,
  mkSingleDir
};
