'use strict';

const log4js = require('log4js');
const configuration = require('./config');
const loggers = require('./loggers');
let initialized = false;

function initialize(newConfiguration, options) {
  if ( initialized ) {
    return;
  }

  if ( configuration !== newConfiguration ) {
    if ( !options ) {
      options = {};
    }

    if ( !('onlyOverride' in options) ) {
      options.onlyOverride = false;
    }

    if ( !options.onlyOverride ) {
      configuration.appenders = {};
      configuration.categories = {};
    }

    const appenders = newConfiguration.appenders;
    const categories = newConfiguration.categories;

    if ( appenders ) {
      const appenderKeys = Object.keys(appenders);
      for ( const appenderKey of appenderKeys ) {
        configuration.appenders[appenderKey] = appenders[appenderKey];
      }
    }

    if ( categories ) {
      const categoryKeys = Object.keys(categories);
      for ( const categoryKey of categoryKeys ) {
        configuration.categories[categoryKey] = categories[categoryKey];
      }
    }
  }

  log4js.configure(configuration);

  const categoryKeys = Object.keys(configuration.categories);
  for ( const categoryKey of categoryKeys ) {
    loggers[categoryKey] = log4js.getLogger(categoryKey);
  }

  initialized = true;
}

module.exports = initialize;
